@@ -1,5 +1,6 @@
-import importlib
 import sys
+import importlib
+import traceback
 from typing import Callable
 
 from meiga import Result, Error, Success, isFailure
@@ -14,5 +15,6 @@ def get_function_from_string(function_string: str) -> Result[Callable, Error]:
         func = getattr(mod, func_name)
         return Success(func)
     except Exception as err:
+        traceback.print_exc()
         print(err, file=sys.stderr)
         return isFailure
